<a id="types-aiobotocore-chime-sdk-voice"></a>

# types-aiobotocore-chime-sdk-voice

[![PyPI - types-aiobotocore-chime-sdk-voice](https://img.shields.io/pypi/v/types-aiobotocore-chime-sdk-voice.svg?color=blue)](https://pypi.org/project/types-aiobotocore-chime-sdk-voice)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-chime-sdk-voice.svg?color=blue)](https://pypi.org/project/types-aiobotocore-chime-sdk-voice)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-chime-sdk-voice?color=blue)](https://pypistats.org/packages/types-aiobotocore-chime-sdk-voice)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.ChimeSDKVoice 2.5.0](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.12.5](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-chime-sdk-voice docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_chime_sdk_voice/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-chime-sdk-voice](#types-aiobotocore-chime-sdk-voice)
  - [How to install](#how-to-install)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `ChimeSDKVoice` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[chime-sdk-voice]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[chime-sdk-voice]'


# standalone installation
python -m pip install types-aiobotocore-chime-sdk-voice
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-chime-sdk-voice
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[chime-sdk-voice]` in your environment:

```bash
python -m pip install 'types-aiobotocore[chime-sdk-voice]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[chime-sdk-voice]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[chime-sdk-voice]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[chime-sdk-voice]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[chime-sdk-voice]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[chime-sdk-voice]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[chime-sdk-voice]` in your environment:

```bash
python -m pip install 'types-aiobotocore[chime-sdk-voice]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[chime-sdk-voice]` in your environment:

```bash
python -m pip install 'types-aiobotocore[chime-sdk-voice]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ChimeSDKVoiceClient` provides annotations for
`session.create_client("chime-sdk-voice")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_chime_sdk_voice import ChimeSDKVoiceClient

session = get_session()
async with session.create_client("chime-sdk-voice") as client:
    client: ChimeSDKVoiceClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_chime_sdk_voice.paginator` module contains type annotations
for all paginators.

```python
from aiobotocore.session import get_session

from types_aiobotocore_chime_sdk_voice import ChimeSDKVoiceClient
from types_aiobotocore_chime_sdk_voice.paginator import (
    ListSipMediaApplicationsPaginator,
    ListSipRulesPaginator,
)

session = get_session()
async with session.create_client("chime-sdk-voice") as client:
    client: ChimeSDKVoiceClient

    # Explicit type annotations are optional here
    # Types should be correctly discovered by mypy and IDEs
    list_sip_media_applications_paginator: ListSipMediaApplicationsPaginator = client.get_paginator(
        "list_sip_media_applications"
    )
    list_sip_rules_paginator: ListSipRulesPaginator = client.get_paginator("list_sip_rules")
```

<a id="literals"></a>

### Literals

`types_aiobotocore_chime_sdk_voice.literals` module contains literals extracted
from shapes that can be used in user code for type checking.

```python
from types_aiobotocore_chime_sdk_voice.literals import (
    AlexaSkillStatusType,
    CallingNameStatusType,
    CapabilityType,
    ErrorCodeType,
    GeoMatchLevelType,
    ListSipMediaApplicationsPaginatorName,
    ListSipRulesPaginatorName,
    NotificationTargetType,
    NumberSelectionBehaviorType,
    OrderedPhoneNumberStatusType,
    OriginationRouteProtocolType,
    PhoneNumberAssociationNameType,
    PhoneNumberOrderStatusType,
    PhoneNumberOrderTypeType,
    PhoneNumberProductTypeType,
    PhoneNumberStatusType,
    PhoneNumberTypeType,
    ProxySessionStatusType,
    SipRuleTriggerTypeType,
    VoiceConnectorAwsRegionType,
    ChimeSDKVoiceServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)


def check_value(value: AlexaSkillStatusType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_chime_sdk_voice.type_defs` module contains structures and
shapes assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_chime_sdk_voice.type_defs import (
    AddressTypeDef,
    AssociatePhoneNumbersWithVoiceConnectorGroupRequestRequestTypeDef,
    PhoneNumberErrorTypeDef,
    ResponseMetadataTypeDef,
    AssociatePhoneNumbersWithVoiceConnectorRequestRequestTypeDef,
    BatchDeletePhoneNumberRequestRequestTypeDef,
    UpdatePhoneNumberRequestItemTypeDef,
    CandidateAddressTypeDef,
    CreatePhoneNumberOrderRequestRequestTypeDef,
    GeoMatchParamsTypeDef,
    CreateSipMediaApplicationCallRequestRequestTypeDef,
    SipMediaApplicationCallTypeDef,
    SipMediaApplicationEndpointTypeDef,
    SipRuleTargetApplicationTypeDef,
    VoiceConnectorItemTypeDef,
    CreateVoiceConnectorRequestRequestTypeDef,
    VoiceConnectorTypeDef,
    CredentialTypeDef,
    DNISEmergencyCallingConfigurationTypeDef,
    DeletePhoneNumberRequestRequestTypeDef,
    DeleteProxySessionRequestRequestTypeDef,
    DeleteSipMediaApplicationRequestRequestTypeDef,
    DeleteSipRuleRequestRequestTypeDef,
    DeleteVoiceConnectorEmergencyCallingConfigurationRequestRequestTypeDef,
    DeleteVoiceConnectorGroupRequestRequestTypeDef,
    DeleteVoiceConnectorOriginationRequestRequestTypeDef,
    DeleteVoiceConnectorProxyRequestRequestTypeDef,
    DeleteVoiceConnectorRequestRequestTypeDef,
    DeleteVoiceConnectorStreamingConfigurationRequestRequestTypeDef,
    DeleteVoiceConnectorTerminationCredentialsRequestRequestTypeDef,
    DeleteVoiceConnectorTerminationRequestRequestTypeDef,
    DisassociatePhoneNumbersFromVoiceConnectorGroupRequestRequestTypeDef,
    DisassociatePhoneNumbersFromVoiceConnectorRequestRequestTypeDef,
    VoiceConnectorSettingsTypeDef,
    GetPhoneNumberOrderRequestRequestTypeDef,
    GetPhoneNumberRequestRequestTypeDef,
    GetProxySessionRequestRequestTypeDef,
    GetSipMediaApplicationAlexaSkillConfigurationRequestRequestTypeDef,
    SipMediaApplicationAlexaSkillConfigurationTypeDef,
    GetSipMediaApplicationLoggingConfigurationRequestRequestTypeDef,
    SipMediaApplicationLoggingConfigurationTypeDef,
    GetSipMediaApplicationRequestRequestTypeDef,
    GetSipRuleRequestRequestTypeDef,
    GetVoiceConnectorEmergencyCallingConfigurationRequestRequestTypeDef,
    GetVoiceConnectorGroupRequestRequestTypeDef,
    GetVoiceConnectorLoggingConfigurationRequestRequestTypeDef,
    LoggingConfigurationTypeDef,
    GetVoiceConnectorOriginationRequestRequestTypeDef,
    GetVoiceConnectorProxyRequestRequestTypeDef,
    ProxyTypeDef,
    GetVoiceConnectorRequestRequestTypeDef,
    GetVoiceConnectorStreamingConfigurationRequestRequestTypeDef,
    GetVoiceConnectorTerminationHealthRequestRequestTypeDef,
    TerminationHealthTypeDef,
    GetVoiceConnectorTerminationRequestRequestTypeDef,
    TerminationTypeDef,
    ListPhoneNumberOrdersRequestRequestTypeDef,
    ListPhoneNumbersRequestRequestTypeDef,
    ListProxySessionsRequestRequestTypeDef,
    PaginatorConfigTypeDef,
    ListSipMediaApplicationsRequestRequestTypeDef,
    ListSipRulesRequestRequestTypeDef,
    ListSupportedPhoneNumberCountriesRequestRequestTypeDef,
    PhoneNumberCountryTypeDef,
    ListVoiceConnectorGroupsRequestRequestTypeDef,
    ListVoiceConnectorTerminationCredentialsRequestRequestTypeDef,
    ListVoiceConnectorsRequestRequestTypeDef,
    OrderedPhoneNumberTypeDef,
    OriginationRouteTypeDef,
    ParticipantTypeDef,
    PhoneNumberAssociationTypeDef,
    PhoneNumberCapabilitiesTypeDef,
    PutVoiceConnectorProxyRequestRequestTypeDef,
    RestorePhoneNumberRequestRequestTypeDef,
    SearchAvailablePhoneNumbersRequestRequestTypeDef,
    StreamingNotificationTargetTypeDef,
    UpdatePhoneNumberRequestRequestTypeDef,
    UpdatePhoneNumberSettingsRequestRequestTypeDef,
    UpdateProxySessionRequestRequestTypeDef,
    UpdateSipMediaApplicationCallRequestRequestTypeDef,
    UpdateVoiceConnectorRequestRequestTypeDef,
    ValidateE911AddressRequestRequestTypeDef,
    AssociatePhoneNumbersWithVoiceConnectorGroupResponseTypeDef,
    AssociatePhoneNumbersWithVoiceConnectorResponseTypeDef,
    BatchDeletePhoneNumberResponseTypeDef,
    BatchUpdatePhoneNumberResponseTypeDef,
    DisassociatePhoneNumbersFromVoiceConnectorGroupResponseTypeDef,
    DisassociatePhoneNumbersFromVoiceConnectorResponseTypeDef,
    EmptyResponseMetadataTypeDef,
    GetPhoneNumberSettingsResponseTypeDef,
    ListAvailableVoiceConnectorRegionsResponseTypeDef,
    ListVoiceConnectorTerminationCredentialsResponseTypeDef,
    SearchAvailablePhoneNumbersResponseTypeDef,
    BatchUpdatePhoneNumberRequestRequestTypeDef,
    ValidateE911AddressResponseTypeDef,
    CreateProxySessionRequestRequestTypeDef,
    CreateSipMediaApplicationCallResponseTypeDef,
    UpdateSipMediaApplicationCallResponseTypeDef,
    CreateSipMediaApplicationRequestRequestTypeDef,
    SipMediaApplicationTypeDef,
    UpdateSipMediaApplicationRequestRequestTypeDef,
    CreateSipRuleRequestRequestTypeDef,
    SipRuleTypeDef,
    UpdateSipRuleRequestRequestTypeDef,
    CreateVoiceConnectorGroupRequestRequestTypeDef,
    UpdateVoiceConnectorGroupRequestRequestTypeDef,
    VoiceConnectorGroupTypeDef,
    CreateVoiceConnectorResponseTypeDef,
    GetVoiceConnectorResponseTypeDef,
    ListVoiceConnectorsResponseTypeDef,
    UpdateVoiceConnectorResponseTypeDef,
    PutVoiceConnectorTerminationCredentialsRequestRequestTypeDef,
    EmergencyCallingConfigurationTypeDef,
    GetGlobalSettingsResponseTypeDef,
    UpdateGlobalSettingsRequestRequestTypeDef,
    GetSipMediaApplicationAlexaSkillConfigurationResponseTypeDef,
    PutSipMediaApplicationAlexaSkillConfigurationRequestRequestTypeDef,
    PutSipMediaApplicationAlexaSkillConfigurationResponseTypeDef,
    GetSipMediaApplicationLoggingConfigurationResponseTypeDef,
    PutSipMediaApplicationLoggingConfigurationRequestRequestTypeDef,
    PutSipMediaApplicationLoggingConfigurationResponseTypeDef,
    GetVoiceConnectorLoggingConfigurationResponseTypeDef,
    PutVoiceConnectorLoggingConfigurationRequestRequestTypeDef,
    PutVoiceConnectorLoggingConfigurationResponseTypeDef,
    GetVoiceConnectorProxyResponseTypeDef,
    PutVoiceConnectorProxyResponseTypeDef,
    GetVoiceConnectorTerminationHealthResponseTypeDef,
    GetVoiceConnectorTerminationResponseTypeDef,
    PutVoiceConnectorTerminationRequestRequestTypeDef,
    PutVoiceConnectorTerminationResponseTypeDef,
    ListSipMediaApplicationsRequestListSipMediaApplicationsPaginateTypeDef,
    ListSipRulesRequestListSipRulesPaginateTypeDef,
    ListSupportedPhoneNumberCountriesResponseTypeDef,
    PhoneNumberOrderTypeDef,
    OriginationTypeDef,
    ProxySessionTypeDef,
    PhoneNumberTypeDef,
    StreamingConfigurationTypeDef,
    CreateSipMediaApplicationResponseTypeDef,
    GetSipMediaApplicationResponseTypeDef,
    ListSipMediaApplicationsResponseTypeDef,
    UpdateSipMediaApplicationResponseTypeDef,
    CreateSipRuleResponseTypeDef,
    GetSipRuleResponseTypeDef,
    ListSipRulesResponseTypeDef,
    UpdateSipRuleResponseTypeDef,
    CreateVoiceConnectorGroupResponseTypeDef,
    GetVoiceConnectorGroupResponseTypeDef,
    ListVoiceConnectorGroupsResponseTypeDef,
    UpdateVoiceConnectorGroupResponseTypeDef,
    GetVoiceConnectorEmergencyCallingConfigurationResponseTypeDef,
    PutVoiceConnectorEmergencyCallingConfigurationRequestRequestTypeDef,
    PutVoiceConnectorEmergencyCallingConfigurationResponseTypeDef,
    CreatePhoneNumberOrderResponseTypeDef,
    GetPhoneNumberOrderResponseTypeDef,
    ListPhoneNumberOrdersResponseTypeDef,
    GetVoiceConnectorOriginationResponseTypeDef,
    PutVoiceConnectorOriginationRequestRequestTypeDef,
    PutVoiceConnectorOriginationResponseTypeDef,
    CreateProxySessionResponseTypeDef,
    GetProxySessionResponseTypeDef,
    ListProxySessionsResponseTypeDef,
    UpdateProxySessionResponseTypeDef,
    GetPhoneNumberResponseTypeDef,
    ListPhoneNumbersResponseTypeDef,
    RestorePhoneNumberResponseTypeDef,
    UpdatePhoneNumberResponseTypeDef,
    GetVoiceConnectorStreamingConfigurationResponseTypeDef,
    PutVoiceConnectorStreamingConfigurationRequestRequestTypeDef,
    PutVoiceConnectorStreamingConfigurationResponseTypeDef,
)


def get_structure() -> AddressTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-chime-sdk-voice` version is the same as related
`aiobotocore` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_chime_sdk_voice/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
